import XConteudo
import OFS
import Globals
from Globals import Persistent
import time
import DateTime
from AccessControl import ClassSecurityInfo
from string import split
from OFS.Folder import Folder
from urllib import quote
from DocumentTemplate.DT_HTML import HTML
from StructuredText.StructuredText import HTML as STXHTML
from OFS.Folder import Folder
from OFS.Cache import Cacheable

_marker = []

class XNoticia ( XConteudo.XConteudo ):
    """Classe que define a XNoticia."""

    meta_type = 'XNoticia'
    friendly_name = 'Notcia'
    security = ClassSecurityInfo()
    categorias = None
    _usar_structured_text = 1

    security.declareProtected('Modificar Propriedades da XNoticia', 'manage_PropertiesForm')
    manage_PropertiesForm = Globals.DTMLFile("dtml/editXNoticiaForm", globals(), in_ZMI=1)

    security.declareProtected('Utilizar Interface de Gerenciamento do ZCoMIX','gadgetPropertiesForm')
    gadgetXNoticiaForm = Globals.DTMLFile("dtml/editXNoticiaForm", globals(), in_ZMI=0)

    security.declareProtected('Utilizar Interface de Gerenciamento do ZCoMIX','manage_ZPropertiesForm')
    manage_ZPropertiesForm = Globals.DTMLFile("dtml/ZTemplate", globals(), in_ZMI=0, z_conteudo='gadgetPropertiesForm')

    def manage_options(self, REQUEST=None):
      manage_options=(
          ({'label':'Propriedades', 'action':'manage_PropertiesForm'},)
          + Folder.manage_options[:1] +
          ({'label':'Visualizar', 'action': '' },)
          + Folder.manage_options[3:]
          + Cacheable.manage_options)

      zcomix_manage_options=((
          {'label':'Propriedades', 'action':'manage_ZPropertiesForm'},
          {'label':'Visualizar', 'action':''},))

      if self.SecurityGetUser().has_permission('View management screens', self):
        return manage_options
      else:
        return zcomix_manage_options

    def __init__(self, id, title):
        self.id = id
        self.title = title

    security.declareProtected('View', 'render')
    def render(self, REQUEST=None, *args, **kw):
        """Retorna o conteudo do objeto como HTML."""
        if not self._cache_namespace_keys:
            data = self.ZCacheable_get(default=_marker)
            if data is not _marker:
                # Return cached results.
                return data

        result = "<h1>%s</h1>\n\n" % self.title_or_id()
        result += "%s\n" % self.getTexto()
        if self._usar_structured_text:
          result = STXHTML(result, level=2, header=0)
        else:
          result=HTML(result,REQUEST=REQUEST,kw=kw)(self)
        if not self._cache_namespace_keys:
            self.ZCacheable_set(result)
        return result

    security.declareProtected('Modificar Propriedades da XNoticia', 'manage_Properties')
    def manage_Properties(self, title, data_inicial='1970/01/01', data_final='2030/01/01',
        mostrar_no_menu=0, texto="", categorias=None, novas_categorias=None, usar_structured_text=0,
		in_ZMI=1, REQUEST=None, *args, **kw):
        "Modifica as Propriedades da XNoticia"
        self.title = title
        try: self.data_inicial = DateTime.DateTime(data_inicial).ISO()
        except: self.data_inicial = '1970/01/01'
        try: self.data_final = DateTime.DateTime(data_final).ISO()
        except: self.data_final = '2030/01/01'
        self._texto = texto
        self._usar_structured_text = usar_structured_text
        if novas_categorias:
            if categorias is None:
              categorias = novas_categorias
            else:
              categorias.extend(novas_categorias)
        if categorias is None:
            categorias = []
        for i in range(0, categorias.count("")):
          try: categorias.remove("")
          except: pass
        self.categorias = categorias
        if self.catalog_principal is not None:
                self.manage_editCataloger(self.catalog_principal)
        self.reindex_object()
        self.ZCacheable_invalidate()
        if REQUEST is not None:
          if in_ZMI:
            return self.manage_PropertiesForm(REQUEST, management_view='Propriedades',
                manage_tabs_message='A Noticia <strong>%s</strong> foi editada.' % self.id
                )
          else:
            return self.manage_ZPropertiesForm(REQUEST, management_view='Propriedades',
                manage_tabs_message='A Noticia <strong>%s</strong> foi editada.' % self.id
                )

Globals.default__class_init__(XNoticia)

def manage_addXNoticia(self, title, produtor='admin', data_producao='1970/01/01',
        data_inicial='1970/01/01', data_final='2030/01/01', mostrar_no_menu=0,
        texto="", categorias=None, novas_categorias=None, usar_structured_text=0, REQUEST=None):
        """Cria um XNoticia e o adiciona ao seu parent Folder.
        O argumento 'self' referencia o parent Folder.
        """

        id = str(int(self.ZopeTime()))
        noticia = XNoticia(id, title)
        noticia.produtor = REQUEST.AUTHENTICATED_USER.getId()
        if novas_categorias:
            if categorias is None:
              categorias = novas_categorias
            else:
              categorias.extend(novas_categorias)
        if categorias is None:
            categorias = []
        for i in range(0, categorias.count("")):
          try: categorias.remove("")
          except: pass
        noticia.categorias = categorias
        t = time.time()
        noticia.data_producao = DateTime.DateTime(t).ISO()
        try: noticia.data_inicial = DateTime.DateTime(data_inicial).ISO()
        except: noticia.data_inicial = '1970/01/01'
        try: noticia.data_final = DateTime.DateTime(data_final).ISO()
        except: noticia.data_final = '2030/01/01'
        noticia._texto = texto
        noticia._usar_structured_text = usar_structured_text
        self._setObject(id, noticia)
        noticia = getattr(self, id)
        if self.catalog_principal is not None:
                noticia.manage_editCataloger(self.catalog_principal)
                getattr(self, self.catalog_principal).catalog_object(noticia, '/' + noticia.absolute_url(relative=1))

        if REQUEST is not None:
                return self.manage_main(self, REQUEST)

manage_addXNoticiaForm = Globals.DTMLFile('dtml/addXNoticiaForm', globals())
