from Globals import InitializeClass
from Globals import Persistent, Acquisition
import Globals
import AccessControl
import OFS
from AccessControl import ClassSecurityInfo
from DocumentTemplate.DT_Util import html_quote
from DocumentTemplate.DT_Var import newline_to_br
from OFS.Cache import Cacheable
from OFS.SimpleItem import Item
from DocumentTemplate.DT_HTML import HTML
from StructuredText.StructuredText import HTML as STXHTML
from XWorkFlow import XWorkFlow

class XParagrafo ( XWorkFlow, Acquisition.Implicit, Persistent, Cacheable, Item ):
    """Classe que define o XParagrafo."""

    title = None
    texto = None
    estilo_css = None
    ordem_layout = 0
    friendly_name = 'Pargrafo'
    _usar_structured_text = 0
    security = ClassSecurityInfo()
    meta_type = 'XParagrafo'

    security.declareProtected('Modificar Propriedades do XParagrafo', 'manage_PropertiesForm')
    manage_PropertiesForm = Globals.DTMLFile("dtml/editXParagrafoForm", globals(), in_ZMI=1)

    security.declareProtected('Utilizar Interface de Gerenciamento do ZCoMIX', 'gadgetPropertiesForm')
    gadgetPropertiesForm = Globals.DTMLFile("dtml/editXParagrafoForm", globals(), in_ZMI=0)

    security.declareProtected('Utilizar Interface de Gerenciamento do ZCoMIX','manage_ZPropertiesForm')
    manage_ZPropertiesForm = Globals.DTMLFile("dtml/ZTemplate", globals(), in_ZMI=0, z_conteudo='gadgetPropertiesForm')

    def manage_options(self, REQUEST=None):
      manage_options=( (
          {'label':'Propriedades', 'action':'manage_PropertiesForm'},
          {'label':'HTML', 'action':'manage_testaXParagrafo'},
          )
          + Item.manage_options
          + Cacheable.manage_options
          )

      zcomix_manage_options=( (
          {'label':'Propriedades', 'action':'manage_ZPropertiesForm'},
          {'label':'Visualizar', 'action':'manage_testaXParagrafo'},))

      if self.SecurityGetUser().has_permission('View management screens', self):
        return manage_options
      else:
        return zcomix_manage_options

    def __init__(self, id, title=None, texto=None):
        self.id = id
        self.title = title
        self.texto = texto

    def usar_structured_text(self):
       return self._usar_structured_text

    security.declareProtected('View', 'render')
    def render(self, REQUEST=None, *args, **kw):
        "Retorna o conteudo do objeto como HTML."
        result = ""
        kw['header'] = 0
        if self.usar_structured_text():
          result=apply(STXHTML, (self.texto, ), kw)
        else:
          result=apply(HTML(newline_to_br(self.texto)), (self, REQUEST), kw)

        if self.estilo_css is not None and not self.usar_structured_text():
                result = "<span class='%s'>%s</span>" % (self.estilo_css, result)

        return result

    security.declareProtected('View', 'manage_testaXParagrafo')
    def manage_testaXParagrafo(self, REQUEST=None):
        "Retorna o conteudo do objeto como HTML. Utilizado na Interface do Zope."
        result = "<html><HEAD>"
        result += "<LINK REL=StyleSheet HREF='%s' TYPE='text/css'>" % self.aq_parent.estilo_css
        result += "</HEAD><BODY>"
        result += self.render()
        result += "</BODY></HTML>"
        return result


    def __call__(self, REQUEST=None):
        "Retorna o conteudo do objeto como HTML."
        return render(self, REQUEST)

    security.declareProtected('Modificar Propriedades da XParagrafo', 'manage_Properties')
    def manage_Properties(self, title=None, texto=None, estilo_css=None, \
         usar_structured_text=0, REQUEST=None):
        "Modifica as Propriedades da XParagrafo"
        self.title = title
        self.texto = texto
        self.estilo_css = estilo_css
        self._usar_structured_text = usar_structured_text

        if REQUEST is not None:
          if in_ZMI:
            return self.manage_PropertiesForm(REQUEST, management_view='Propriedades',
                manage_tabs_message='O Paragrafo <strong>%s</strong> foi editado.' % self.id
                )
          else:
            return self.manage_ZPropertiesForm(REQUEST, management_view='Propriedades',
                manage_tabs_message='O Paragrafo <strong>%s</strong> foi editado.' % self.id
                )

InitializeClass(XParagrafo)

def manage_addXParagrafo(self, id, title=None, texto=None, estilo_css=None, \
        REQUEST=None):
        """Cria um XParagrafo e o adiciona ao seu parent Folder.
        O argumento 'self' referencia o parent Folder.
        """
        paragrafo = XParagrafo(id, title, texto)
        paragrafo.estilo_css = estilo_css
        self._setObject(id, paragrafo)
        if REQUEST is not None:
                return self.manage_main(self, REQUEST)

manage_addXParagrafoForm = Globals.HTMLFile('dtml/addXParagrafoForm', globals())
