import Globals
from Globals import Persistent, Acquisition
import AccessControl
import OFS
import sys
from AccessControl import ClassSecurityInfo
import Products
from XWorkFlow import XWorkFlow
from AccessControl.Role import RoleManager
import time
import DateTime

class XTemplate ( XWorkFlow, Acquisition.Implicit, Persistent, RoleManager, OFS.Folder.Folder ):
    """Classe que define o XTemplate."""

    security = ClassSecurityInfo()

    data_inicial = "1970/01/01"
    data_final = "2030/01/01"
    property_extensible_schema__ = 1
    friendly_name = 'Template'
    meta_type = 'XTemplate'

    security.declareProtected('Modificar Propriedades do XTemplate','manage_PropertiesForm')
    manage_PropertiesForm = Globals.DTMLFile("dtml/editXTemplateForm", globals(), in_ZMI=1)

    security.declareProtected('Utilizar Interface de Gerenciamento do ZCoMIX','gadgetPropertiesForm')
    gadgetPropertiesForm = Globals.DTMLFile("dtml/editXSiteForm", globals(), in_ZMI=0)

    security.declareProtected('Utilizar Interface de Gerenciamento do ZCoMIX','manage_ZPropertiesForm')
    manage_ZPropertiesForm = Globals.DTMLFile("dtml/ZTemplate", globals(), in_ZMI=0, z_conteudo='gadgetPropertiesForm')

    def filtered_propertyMap(self):
        result = []
        for i in self.propertyMap():
           if 'd' in i.get('mode', 'awd'):
             result.append(i)
        return result

    def __setstate__(self, state):
        XWorkFlow.__setstate__(self, state)

    def all_meta_types(self):
        """ What can you put inside me? """
        f = lambda x: x['name'] in ('DTML Method', 'DTML Document', 'Image', 'Z SQL Method',  'Script (Python)',
                                                'Folder', 'File', 'XLink', 'Z Style Sheet',
                                                'Z MySQL Database Connection', 'Symlink')
        return filter(f, Products.meta_types)

    _properties = (
        {'id':'title','type':'string','mode':'w'},
        {'id':'data_inicial','type':'date','mode':'w' },
        {'id':'data_final','type':'date','mode':'w' },
        )

    def manage_options(self, REQUEST=None):
        manage_options=(OFS.Folder.Folder.manage_options[:1] +(
            {'label':'Propriedades', 'action':'manage_PropertiesForm'},
            {'label':'View', 'action':''},
            )
            + OFS.Folder.Folder.manage_options[3:]
            + OFS.Cache.Cacheable.manage_options)

        zcomix_manage_options=((
            {'label':'Propriedades', 'action':'manage_ZPropertiesForm'},
            {'label':'Visualizar', 'action':''},
            )
        )

        if self.SecurityGetUser().has_permission('View management screens', self):
          return manage_options
        else:
          return zcomix_manage_options

    def __init__(self, id, title):
        self.id = id
        self.title = title

    def __bobo_traverse__(self, request, entry_name):
        """Faz um Mirror do Template Principal."""
        mid = self.template_principal
        mf = getattr(self, mid, None)
        path= getattr(request,'TraversalRequestNameStack',None)
        if (entry_name != mid) and mf and (path is not None) and (self.getId()!=mid):
                path= path[:]
                context= mf;
                path.append(self.getId())
                path.append(entry_name)
                path.reverse()
                for s in path:
                        try: ncontext = context.restrictedTraverse(s)
                        except: break
                        if not hasattr(ncontext,'__basicnew__'): break
                        context= ncontext
                self = self.__of__(context)
        return getattr(self, entry_name)

    old_manage_addProperty = OFS.PropertyManager.PropertyManager.manage_addProperty
    old_manage_delProperties = OFS.PropertyManager.PropertyManager.manage_delProperties
    old_manage_changeProperties = OFS.PropertyManager.PropertyManager.manage_changeProperties

    security.declareProtected('Modificar Propriedades do XTemplate','manage_addProperty')
    def manage_addProperty(self, id, value, type, in_ZMI=1, REQUEST=None, *args, **kw):
        "Modifica as Propriedades do XTemplate"
        self.old_manage_addProperty(id=id, value=value, type=type, REQUEST=None)
        if REQUEST is not None:
          if in_ZMI==1:
                return self.manage_PropertiesForm(REQUEST, management_view = 'Propriedades',
                        manage_tabs_message='O Template <strong>%s</strong> foi editado.' % self.id)
          else:
                return self.manage_ZPropertiesForm(REQUEST, management_view = 'Propriedades',
                        manage_tabs_message='O Template <strong>%s</strong> foi editado.' % self.id)

    security.declareProtected('Modificar Propriedades do XTemplate','manage_delProperties')
    def manage_delProperties(self, ids, in_ZMI=1, REQUEST=None, *args, **kw):
        "Modifica as Propriedades do XTemplate"
        self.old_manage_delProperties(ids, REQUEST=None)
        if REQUEST is not None:
          if in_ZMI==1:
                return self.manage_PropertiesForm(REQUEST, management_view = 'Propriedades',
                        manage_tabs_message='O Template <strong>%s</strong> foi editado.' % self.id)
          else:
                return self.manage_ZPropertiesForm(REQUEST, management_view = 'Propriedades',
                        manage_tabs_message='O Template <strong>%s</strong> foi editado.' % self.id)

    security.declareProtected('Modificar Propriedades do XTemplate','manage_changeProperties')
    def manage_changeProperties(self, in_ZMI=1, REQUEST=None, *args, **kw):
        "Modifica as Propriedades do XTemplate"
        if kw:
                apply(self.old_manage_changeProperties, [], kw)
        else:
                apply(self.old_manage_changeProperties, [], REQUEST.form)

        if REQUEST is not None:
          if in_ZMI==1:
                return self.manage_PropertiesForm(REQUEST, management_view = 'Propriedades',
                        manage_tabs_message='O Template <strong>%s</strong> foi editado.' % self.id)
          else:
                return self.manage_ZPropertiesForm(REQUEST, management_view = 'Propriedades',
                        manage_tabs_message='O Template <strong>%s</strong> foi editado.' % self.id)

    security.declareProtected('Modificar Propriedades do XTemplate','manage_Properties')
    def manage_Properties(self, title, data_inicial='1970/01/01', data_final='2030/01/01', in_ZMI=1, REQUEST=None, *args, **kw):
        "Modifica as Propriedades do XTemplate"
        self.title = title
        try: self.data_inicial = DateTime.DateTime(data_inicial).ISO()
        except: self.data_inicial = '1970/01/01'
        try: self.data_final = DateTime.DateTime(data_final).ISO()
        except: self.data_final = '2030/01/01'
        if REQUEST is not None:
          if in_ZMI==1:
                return self.manage_PropertiesForm(REQUEST, management_view = 'Propriedades',
                        manage_tabs_message='O Template <strong>%s</strong> foi editado.' % self.id)
          else:
                return self.manage_ZPropertiesForm(REQUEST, management_view = 'Propriedades',
                        manage_tabs_message='O Template <strong>%s</strong> foi editado.' % self.id)

Globals.default__class_init__(XTemplate)

def manage_addXTemplate(self, id, title, data_inicial='1970/01/01', data_final='2030/01/01', REQUEST=None):
    """Cria um XTemplate e o adiciona ao seu parent Folder.
    O argumento 'self' referencia o  parent Folder.
    """
    template = XTemplate(id, title)
    try: template.data_inicial = DateTime.DateTime(data_inicial).ISO()
    except: template.data_inicial = '1970/01/01'
    try: template.data_final = DateTime.DateTime(data_final).ISO()
    except: template.data_final = '2030/01/01'
    self._setObject(id, template)
    if REQUEST is not None:
        return self.manage_main(self, REQUEST)

manage_addXTemplateForm = Globals.HTMLFile('dtml/addXTemplateForm', globals())
